// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
/*

    Copyright (C) 2012-2017  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;
const PanelTools = Me.imports.panelTools;

function _getActivities() {
    if (Convenience.checkGSV(3, 4)) {
        try { return Main.panel._activitiesButton; } catch(e) { return null; }
    } else {
        try { return Main.panel.statusArea.activities; } catch(e) { return null; }
    }
}

function _getActivitiesHotCorner() {
    if (Convenience.checkGSV(3, 4)) {
        try { return Main.panel._activitiesButton._hotCorner; } catch(e) { return null; }
    } else if (Convenience.checkGSV(3, 6)) {
        try { return Main.panel.statusArea.activities.hotCorner; } catch(e) { return null; }
    }
    return null;
}

const GNOME_ACTIVITIES = _getActivities();
const GNOME_ACTIVITIES_HOTCORNER = _getActivitiesHotCorner();

const KEY_SHOW_ACTIVITIES = 'show-activities';

const ActivitiesButton = new Lang.Class({
    Name: 'ActivitiesButton',

    _init: function() {
        if (GNOME_ACTIVITIES_HOTCORNER) GNOME_ACTIVITIES_HOTCORNER.actor.hide()
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_ACTIVITIES, Lang.bind(this, this._onShowActivities));
        this._onShowActivities();
    },

    _onShowActivities: function() {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_ACTIVITIES));
    },

    _updateVisibility: function(visible) {
        GNOME_ACTIVITIES.actor.visible = visible;
        PanelTools.updatePanelCorner(GNOME_ACTIVITIES, 'left');
    },

    destroy: function() {
        this._settings.disconnect(this._connectSettings);
        this._updateVisibility(true);
        if (GNOME_ACTIVITIES_HOTCORNER) GNOME_ACTIVITIES_HOTCORNER.actor.show()
    }
});

function getExtension() {
    return GNOME_ACTIVITIES ? new ActivitiesButton() : null;
}
