// -*- mode: js2; indent-tabs-mode: nil; js2-basic-offset: 4 -*-
/*

    Copyright (C) 2012-2017  Dieter Schärf <ds@dschaerf.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program. If not, see <http://www.gnu.org/licenses/>.

 */

const Lang = imports.lang;

const ExtensionSystem = imports.ui.extensionSystem;
const Main = imports.ui.main;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();
const Convenience = Me.imports.convenience;

const KEY_SHOW_DROPDOWN_ARROW = 'show-dropdown-arrow';

const DropDownArrow = new Lang.Class({
    Name: 'DropDownArrow',

    _init: function() {
        this._settings = Convenience.getSettings(Convenience.CURRENT_SETTINGS_SCHEMA);
        this._connectSettings = this._settings.connect('changed::'+KEY_SHOW_DROPDOWN_ARROW, Lang.bind(this, this._onShowDropDownArrow));
        this._connectExtensionSystem = ExtensionSystem.connect('extension-state-changed', Lang.bind(this, this._onShowDropDownArrow));
        this._onShowDropDownArrow();
    },

    _onShowDropDownArrow: function() {
        this._updateVisibility(this._settings.get_boolean(KEY_SHOW_DROPDOWN_ARROW));
    },

    _updateVisibility: function(visible, actor) {
        if (!actor) {
            for each(let indicator in Main.panel.statusArea) {
                if (indicator.actor) this._updateVisibility(visible, indicator.actor);
            }
        } else {
            if (actor.text == '\u25BE' || (actor.has_style_class_name && actor.has_style_class_name('popup-menu-arrow'))) {
                actor.visible = visible;
            } else if (actor.get_children) {
                let children = actor.get_children();
                for each(let child in children) {
                    this._updateVisibility(visible, child);
                }
             }
        }
    },

    destroy: function() {
        ExtensionSystem.disconnect(this._connectExtensionSystem);
        this._settings.disconnect(this._connectSettings);
        this._updateVisibility(true);
    }
});

function getExtension() {
    return Convenience.checkGSV(3, 4) || Convenience.checkGSV(3, 6) || Convenience.checkGSV(3, 8) ? null : new DropDownArrow();
}
